@@ -3,7 +3,7 @@
 {
     'name': 'German Chart of Accounts SKR03',
     'name_de_DE': 'Deutscher Kontenrahmen SKR03',
-    'version': '1.6.0',
+    'version': '2.2.0',
     'author': 'virtual things',
     'email': 'info@virtual-things.biz',
     'website': 'http://www.virtual-things.biz/',
@@ -26,6 +26,6 @@
         'account_de.xml',
     ],
     'translation': [
-        'de_DE.csv',
+        'locale/de_DE.po',
     ],
 }
